@@ -1,5 +1,6 @@
 import asyncio
 
+from tracardi_remote_call.model.configuration import Content
 from tracardi_remote_call.plugin import RemoteCallAction
 
 
@@ -11,16 +12,22 @@ async def main():
         "headers": [
             ("X-AAA", "test")
         ],
-        "cookies": {}
+        "cookies": {},
+        "body": Content(
+            content="""
+            {"test": {
+            "a": 1,
+            "b": [1, 2]
+            }} 
+            """,
+            type="application/json"
+        )
     }
 
     plugin = RemoteCallAction(**init)
 
     payload = {
-        "test": {
-            "a": 1,
-            "b": [1, 2]
-        }
+
     }
 
     result = await plugin.run(payload)
